@@ -6,7 +6,8 @@ from fxq.commons import dict_merge
 class Environment:
     PROPERTY_FILE_PREFIX = 'app'
 
-    def __init__(self, active_profiles=[]):
+    def __init__(self, active_profiles=[], base_dir=""):
+        self._base_dir = base_dir
         self.active_profiles = active_profiles
         self._properties = {}
         self._load_properties()
@@ -25,13 +26,15 @@ class Environment:
 
     def _load_properties(self):
         # Load Initial no-profile file
-        self._properties = yaml.load(open(f"{Environment.PROPERTY_FILE_PREFIX}.yml").read(), Loader=yaml.SafeLoader)
+        base_dir = f"{self._base_dir}/" if self._base_dir != "" else ""
+        self._properties = yaml.load(open(f"{base_dir}{Environment.PROPERTY_FILE_PREFIX}.yml").read(),
+                                     Loader=yaml.SafeLoader)
 
         # Load profile files if any active profiles are set
         for p in self.active_profiles:
             dict_merge(
                 self._properties,
-                yaml.load(open(f"{Environment.PROPERTY_FILE_PREFIX}.{p}.yml").read(), Loader=yaml.SafeLoader)
+                yaml.load(open(f"{base_dir}{Environment.PROPERTY_FILE_PREFIX}.{p}.yml").read(), Loader=yaml.SafeLoader)
             )
 
 
